
.. image:: https://img.shields.io/travis/ssato/python-anyconfig-configobj-backend.svg
   :target: https://travis-ci.org/ssato/python-anyconfig-configobj-backend
   :alt: Test status

.. image:: https://img.shields.io/coveralls/ssato/python-anyconfig-configobj-backend.svg
   :target: https://coveralls.io/r/ssato/python-anyconfig-configobj-backend
   :alt: Coverage Status

.. image:: https://landscape.io/github/ssato/python-anyconfig-configobj-backend/master/landscape.png
   :target: https://landscape.io/github/ssato/python-anyconfig-configobj-backend/master
   :alt: Code Health

.. image:: https://readthedocs.org/projects/python-anyconfig-configobj-backend/badge/?version=latest
   :target: http://python-anyconfig-configobj-backend.readthedocs.io/en/latest/?badge=latest
   :alt: Doc Status

.. vim:sw=2:ts=2:et:
